from pydantic import BaseModel
from datetime import datetime
from typing import Optional

# Shared properties
class TodoBase(BaseModel):
    title: str
    description: Optional[str] = None
    completed: bool = False
    due_date: Optional[datetime] = None

# Properties to receive on creation
class TodoCreate(TodoBase):
    pass

# Properties to receive on update
class TodoUpdate(TodoBase):
    title: Optional[str] = None
    completed: Optional[bool] = None
    due_date: Optional[datetime] = None

# Properties shared by models stored in DB
class TodoInDBBase(TodoBase):
    id: int
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True

# Properties to return to client
class Todo(TodoInDBBase):
    pass